==> m4e_sdk-0.0.4-dev.7.tar.gz: lib/src/m4e_sdk_initialize.dart <==
import 'package:data_connection_checker/data_connection_checker.dart';
import 'package:dio/dio.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:get_it/get_it.dart';
import 'package:flutter/foundation.dart';

import 'core/core.dart';
import 'data/api/apis.dart';
import 'data/services/services.dart';

/// GETIt instatiation
GetIt m4eSDK = GetIt.instance;

/// Initializes the m4e sdk
/// with specified SDKConfig env
///
/// Example initialization:
///
/// Note: before initializing m4eSDK, you should call `WidgetsFlutterBinding.ensureInitialized()` method
/// as of `flutter --version 1.12` to ensure that your application has been properly
/// initialized before initializing the m4eSDK
///
/// This should be initialized in the entrance level
/// of the application ie `main.dart` before `runApp` method is called.
///
/// ```
/// import 'package:m4edart/m4e_sdk_initialize.dart' as sdk;
///
/// void main() {
///
///   WidgetsFlutterBinding.ensureInitialized();
///
///   sdk.initializeM4eSDK(config: SDKConfig(...));
///
///   runApp(...)
/// }
/// ```
///
void initializeM4eSDK({@required M4eSDKConfig config}) {
  assert(config != null, 'initializeM4eSDK [config] should not be null');
  //! services
  m4eSDK.registerLazySingleton(
      () => M4eAuthService(authApi: m4eSDK(), connectionChecker: m4eSDK()));

  m4eSDK.registerLazySingleton(
    () => M4eTransactionService(
        transactionApi: m4eSDK(),
        walletApi: m4eSDK(),
        connectionChecker: m4eSDK()),
  );

  m4eSDK.registerLazySingleton(
      () => M4eUserService(userApi: m4eSDK(), connectionChecker: m4eSDK()));

  m4eSDK.registerLazySingleton(
    () => M4eWalletService(
        walletApi: m4eSDK(),
        permissionApi: m4eSDK(),
        connectionChecker: m4eSDK()),
  );

  // m4eSDK.registerLazySingleton(() => M4ePermissionService(
  //     permissionApi: m4eSDK(), connectionChecker: m4eSDK()));

  //! APIS
  m4eSDK.registerLazySingleton<AuthApi>(() => AuthApiImpl(
      client: m4eSDK(), storage: m4eSDK(), loggingInterceptor: m4eSDK()));

  m4eSDK.registerLazySingleton<TransactionApi>(
    () => TransactionApiImpl(
      client: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  m4eSDK.registerLazySingleton<UserApi>(
    () => UserApiImpl(
      client: m4eSDK(),
      storage: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  m4eSDK.registerLazySingleton<WalletApi>(
    () => WalletApiImpl(
      client: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  m4eSDK.registerLazySingleton<PermissionApi>(
    () => PermissionApiImpl(
      client: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  // //! request interceptors
  m4eSDK.registerLazySingleton(() => M4eLoggingInterceptors());
  m4eSDK.registerLazySingleton(
      () => M4eHeaderInterceptors(dio: m4eSDK(), authApi: m4eSDK()));

  //! external dependencies
  // data connection checker
  m4eSDK.registerLazySingleton(() => DataConnectionChecker());

  // local storage
  m4eSDK.registerLazySingleton(() => FlutterSecureStorage());

  // http client (dio)
  BaseOptions _options = BaseOptions(
    baseUrl: config.baseUrl,
    connectTimeout: M4eClientRequest.kConnectionTimeout,
    receiveTimeout: M4eClientRequest.kRecieveTimeout,
  );
  m4eSDK.registerLazySingleton(() => Dio(_options));
}

==> m4e_sdk-0.0.5-dev.4.tar.gz: lib/src/m4e_sdk_initialize.dart <==
import 'package:data_connection_checker/data_connection_checker.dart';
import 'package:dio/dio.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:get_it/get_it.dart';
import 'package:flutter/foundation.dart';

import 'core/core.dart';
import 'data/api/apis.dart';
import 'data/services/services.dart';

/// GETIt instatiation
GetIt m4eSDK = GetIt.instance;

/// Initializes the m4e sdk
/// with specified SDKConfig env
///
/// Example initialization:
///
/// Note: before initializing m4eSDK, you should call `WidgetsFlutterBinding.ensureInitialized()` method
/// as of `flutter --version 1.12` to ensure that your application has been properly
/// initialized before initializing the m4eSDK
///
/// This should be initialized in the entrance level
/// of the application ie `main.dart` before `runApp` method is called.
///
/// ```
/// import 'package:m4edart/m4e_sdk_initialize.dart' as sdk;
///
/// void main() {
///
///   WidgetsFlutterBinding.ensureInitialized();
///
///   sdk.initializeM4eSDK(config: SDKConfig(...));
///
///   runApp(...)
/// }
/// ```
///
void initializeM4eSDK({@required M4eSDKConfig config}) {
  assert(config != null, 'initializeM4eSDK [config] should not be null');
  //! services
  m4eSDK.registerLazySingleton(
      () => M4eAuthService(authApi: m4eSDK(), connectionChecker: m4eSDK()));

  m4eSDK.registerLazySingleton(
      () => M4eGroupService(groupApi: m4eSDK(), authApi: m4eSDK() , connectionChecker: m4eSDK()));

  m4eSDK.registerLazySingleton(
    () => M4eTransactionService(
        transactionApi: m4eSDK(),
        walletApi: m4eSDK(),
        connectionChecker: m4eSDK()),
  );

  m4eSDK.registerLazySingleton(
      () => M4eUserService(userApi: m4eSDK(), connectionChecker: m4eSDK()));

  m4eSDK.registerLazySingleton(
    () => M4eWalletService(
        walletApi: m4eSDK(),
        permissionApi: m4eSDK(),
        connectionChecker: m4eSDK()),
  );

  m4eSDK.registerLazySingleton(() => M4ePermissionService(
      permissionApi: m4eSDK(), connectionChecker: m4eSDK()));

  //! APIS
  m4eSDK.registerLazySingleton<AuthApi>(() => AuthApiImpl(
      client: m4eSDK(), storage: m4eSDK(), loggingInterceptor: m4eSDK()));

  m4eSDK.registerLazySingleton<GroupApi>(
    () => GroupApiImpl(
        client: m4eSDK(),
        loggingInterceptor: m4eSDK(),
        headerInterceptor: m4eSDK()),
  );

  m4eSDK.registerLazySingleton<TransactionApi>(
    () => TransactionApiImpl(
      client: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  m4eSDK.registerLazySingleton<UserApi>(
    () => UserApiImpl(
      client: m4eSDK(),
      storage: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  m4eSDK.registerLazySingleton<WalletApi>(
    () => WalletApiImpl(
      client: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  m4eSDK.registerLazySingleton<PermissionApi>(
    () => PermissionApiImpl(
      client: m4eSDK(),
      loggingInterceptor: m4eSDK(),
      headerInterceptor: m4eSDK(),
    ),
  );

  // //! request interceptors
  m4eSDK.registerLazySingleton(() => M4eLoggingInterceptors());
  m4eSDK.registerLazySingleton(
      () => M4eHeaderInterceptors(dio: m4eSDK(), authApi: m4eSDK()));

  //! external dependencies
  // data connection checker
  m4eSDK.registerLazySingleton(() => DataConnectionChecker());

  // local storage
  m4eSDK.registerLazySingleton(() => FlutterSecureStorage());

  // http client (dio)
  BaseOptions _options = BaseOptions(
    baseUrl: config.baseUrl,
    connectTimeout: M4eClientRequest.kConnectionTimeout,
    receiveTimeout: M4eClientRequest.kRecieveTimeout,
  );
  m4eSDK.registerLazySingleton(() => Dio(_options));
}
